@@ -118,7 +118,7 @@ def MonteCarlo(net,Xtest,Ytest,M,Wstd,Bstd,force,Derr=0,net_name="Network",custo
 			_,accuracy = net.evaluate(Xtest,Ytest,verbose=0,use_multiprocessing=True)
 			return accuracy	
 
-	def MCsim(net,Xtest,Ytest,M,Wstd,Bstd,force,Derr=0,net_name="Network",custom_objects=None,dtype='float32',
+	def MCsim(net,Xtest,Ytest,M,Wstd,Bstd,force,Derr=0,net_name="Network",custom_objects=custom_objects,dtype='float32',
 	optimizer=tf.keras.optimizers.SGD(learning_rate=0.1,momentum=0.9),loss=['sparse_categorical_crossentropy'],metrics=['accuracy'],top5=False):
 		acc_noisy = np.zeros((M,1)) #Initilize the variable where im going to save the noisy accuracy
 		top5acc_noisy = np.zeros((M,1)) #Initilize the variable where im going to save the noisy accuracy   top5
@@ -250,4 +250,4 @@ def plotBox(data,labels,legends,color,color_fill,path):
 		ax.spines['bottom'].set_linewidth(1.4)
 		ax.spines['left'].set_linewidth(1.4)
 		plt.savefig(path+'.png')   
-	return plotters(data,labels,legends,color,color_fill,path)
+	return plotBox(data,labels,legends,color,color_fill,path)
